windows: Rename close_current_window to windows_close_current

Change-Id: I77f54a95dca865b91c7ba4f51212e43a049bc62a
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/windows.c b/windows.c
index 2c3f48b..2ec8b9a 100644
--- a/windows.c
+++ b/windows.c
@@ -377,7 +377,7 @@
 }
 
 /*
  * close_current_window() - Close the current (active) window
  * @context:   		The mbox context pointer
  * @set_bmc_event:	Whether to set the bmc event bit
  * @flags:		Flags as defined for a close command in the protocol
@@ -388,7 +388,7 @@
  * without the host requesting it the bmc event bit must be set to indicate this
  * to the host (set_bmc_event == true).
  */
-void close_current_window(struct mbox_context *context, bool set_bmc_event,
+void windows_close_current(struct mbox_context *context, bool set_bmc_event,
 			  uint8_t flags)
 {
 	MSG_DBG("Close current window, flags: 0x%.2x\n", flags);
@@ -434,7 +434,7 @@
 	MSG_DBG("Resetting all windows\n");
 	/* We might have an open window which needs closing */
 	if (context->current) {
-		close_current_window(context, set_bmc_event, FLAGS_NONE);
+		windows_close_current(context, set_bmc_event, FLAGS_NONE);
 	}
 	for (i = 0; i < context->windows.num; i++) {
 		reset_window(context, &context->windows.window[i]);
@@ -377,7 +377,7 @@
 
 /*
- * close_current_window() - Close the current (active) window
+ * windows_close_current() - Close the current (active) window
  * @context:   		The mbox context pointer
  * @set_bmc_event:	Whether to set the bmc event bit